from unittest import TestCase
from pathlib import Path

from sohstationviewer.model.mseed_data.mseed_helper import (
    retrieve_nets_from_data_dict, read_text
)

TEST_DATA_DIR = Path(__file__).resolve().parent.parent.parent.joinpath(
    'test_data')
text_file = TEST_DATA_DIR.joinpath(
    "Pegasus-sample/Pegasus_SVC4/logs/2020/XX/KC01/XX.KC01...D.2020.129")
binary_file = TEST_DATA_DIR.joinpath(
    "Pegasus-sample/Pegasus_SVC4/soh/2020/XX/KC01/VDT.D/"
    "XX.KC01..VDT.D.2020.129")


class TestReadText(TestCase):
    def test_text_file(self):
        ret = read_text(text_file)
        expected_ret = (
            "\n\n** STATE OF HEALTH: XX.KC01...D.2020.129"
            "\n2020-05-08 22:55:45.390 UTC: I(Initializations): Firmware")
        self.assertEqual(ret[:100], expected_ret
                         )

    def test_binary_file(self):
        ret = read_text(binary_file)
        self.assertIsNone(ret)


class TestRetrieveNetsFromDataDict(TestCase):
    def setUp(self):
        self.nets_by_sta = {}
        self.data_dict = {
            'STA1': {'CHA1': {'nets': {'NET1', 'NET2'}},
                     'CHA2': {'nets': {'NET2', 'NET3'}}
                     },
            'STA2': {'CHA1': {'nets': {'NET1'}},
                     'CHA2': {'nets': {'NET1'}}
                     }
            }

    def test_retrieve_nets(self):
        retrieve_nets_from_data_dict(self.data_dict, self.nets_by_sta)
        self.assertEqual(list(self.nets_by_sta.keys()), ['STA1', 'STA2'])
        self.assertEqual(sorted(list(self.nets_by_sta['STA1'])),
                         ['NET1', 'NET2', 'NET3'])
        self.assertEqual(sorted(list(self.nets_by_sta['STA2'])), ['NET1'])
